@@ -18,13 +18,13 @@
 
 #include <signal.h>
 #include <string.h>
-#include "core/bioseq.h"
+#include "core/bioseq_api.h"
 #include "core/cstr_api.h"
 #include "core/disc_distri_api.h"
 #include "core/dynalloc.h"
 #include "core/encseq.h"
-#include "core/fa.h"
-#include "core/fasta.h"
+#include "core/fa_api.h"
+#include "core/fasta_api.h"
 #include "core/fasta_reader_fsm.h"
 #include "core/fasta_reader_rec.h"
 #include "core/fasta_reader_seqit.h"
@@ -32,15 +32,15 @@
 #include "core/gc_content.h"
 #include "core/hashmap_api.h"
 #include "core/hashmap-generic.h"
-#include "core/ma.h"
-#include "core/md5_tab.h"
+#include "core/ma_api.h"
+#include "core/md5_tab_api.h"
 #include "core/parseutils.h"
 #include "core/sig.h"
 #include "core/str_array.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
-#include "core/xposix.h"
+#include "core/xposix_api.h"
 
 struct GtBioseq {
   bool use_stdin;
