@@ -17,13 +17,13 @@
 
 #include <limits.h>
 #include <string.h>
-#include "core/ensure.h"
+#include "core/ensure_api.h"
 #include "core/interval_tree.h"
-#include "core/ma.h"
-#include "core/mathsupport.h"
-#include "core/minmax.h"
-#include "core/range.h"
-#include "core/str.h"
+#include "core/ma_api.h"
+#include "core/mathsupport_api.h"
+#include "core/minmax_api.h"
+#include "core/range_api.h"
+#include "core/str_api.h"
 #include "core/unused_api.h"
 
 typedef enum GtIntervalTreeNodeColor {
@@ -269,7 +269,7 @@ static void interval_tree_max_fixup(GtIntervalTree *it,
     else if (x->right == it->nil && x->left != it->nil)
       x->max = x->left->max;
     else if (x->right != it->nil && x->left != it->nil)
-      x->max = MAX(x->left->max, x->right->max);
+      x->max = GT_MAX(x->left->max, x->right->max);
     x = x->parent;
   }
 }
