@@ -15,11 +15,11 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include "core/ensure.h"
-#include "core/minmax.h"
+#include "core/ensure_api.h"
+#include "core/minmax_api.h"
 #include "core/msort.h"
-#include "core/range.h"
-#include "core/safearith.h"
+#include "core/range_api.h"
+#include "core/safearith_api.h"
 #include "core/undef_api.h"
 
 int gt_range_compare(const GtRange *range_a, const GtRange *range_b)
@@ -43,10 +43,10 @@ int gt_range_compare_with_delta(const GtRange *range_a, const GtRange *range_b,
 
   gt_assert(range_a->start <= range_a->end && range_b->start <= range_b->end);
 
-  start_min = MIN(range_a->start, range_b->start);
-  start_max = MAX(range_a->start, range_b->start);
-  end_min   = MIN(range_a->end, range_b->end);
-  end_max   = MAX(range_a->end, range_b->end);
+  start_min = GT_MIN(range_a->start, range_b->start);
+  start_max = GT_MAX(range_a->start, range_b->start);
+  end_min   = GT_MIN(range_a->end, range_b->end);
+  end_max   = GT_MAX(range_a->end, range_b->end);
 
   if (start_max - start_min <= delta && end_max - end_min <= delta)
     return 0; /* range_a == range_b */
