@@ -20,9 +20,9 @@
 #include "core/assert_api.h"
 #include "core/cstr_api.h"
 #include "core/dynalloc.h"
-#include "core/ensure.h"
-#include "core/ma.h"
-#include "core/str.h"
+#include "core/ensure_api.h"
+#include "core/ma_api.h"
+#include "core/str_api.h"
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
 
