@@ -18,13 +18,13 @@
 #include "core/byte_popcount_api.h"
 #include "core/byte_select_api.h"
 #include "core/combinatorics.h"
-#include "core/ensure.h"
-#include "core/fa.h"
+#include "core/ensure_api.h"
+#include "core/fa_api.h"
 #include "core/fileutils_api.h"
 #include "core/log_api.h"
 #include "core/ma_api.h"
-#include "core/mathsupport.h"
-#include "core/safearith.h"
+#include "core/mathsupport_api.h"
+#include "core/safearith_api.h"
 #include "core/unused_api.h"
 #include "extended/compressed_bitsequence.h"
 #include "extended/popcount_tab.h"
