@@ -18,7 +18,7 @@
 #ifndef MUTATE_H
 #define MUTATE_H
 
-#include "core/seq.h"
+#include "core/seq_api.h"
 
 /* returns a GtSeq which is the mutated sequence <orig_seq> of length <len> over
    alphabet <alpha>. <rate> denotes the error rate (must be >=0 && <= 100) */
