@@ -50,14 +50,14 @@
 #include <stdlib.h>
 #include <string.h>
 #include "core/assert_api.h"
-#include "core/ensure.h"
+#include "core/ensure_api.h"
 #include "core/error_api.h"
-#include "core/ma.h"
-#include "core/mathsupport.h"
+#include "core/ma_api.h"
+#include "core/mathsupport_api.h"
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
-#include "core/yarandom.h"
-#include "extended/rbtree.h"
+#include "core/yarandom_api.h"
+#include "extended/rbtree_api.h"
 
 #ifndef HEIGHT_LIMIT
 #define HEIGHT_LIMIT 64
