@@ -18,22 +18,22 @@
 #include <ctype.h>
 #include <string.h>
 
-#include "core/bioseq.h"
+#include "core/bioseq_api.h"
 #include "core/encseq.h"
 #include "core/fileutils_api.h"
 #include "core/log.h"
 #include "core/logger.h"
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/option_api.h"
 #include "core/output_file_api.h"
-#include "core/range.h"
-#include "core/safearith.h"
+#include "core/range_api.h"
+#include "core/safearith_api.h"
 #include "core/unused_api.h"
 #include "core/warning_api.h"
 #include "extended/gff3_in_stream.h"
 #include "extended/gff3_out_stream_api.h"
 #include "extended/region_mapping.h"
-#include "extended/seqid2file.h"
+#include "extended/seqid2file_api.h"
 #include "extended/visitor_stream.h"
 #include "ltr/gt_ltrdigest.h"
 #include "ltr/ltr_input_check_visitor.h"
