@@ -21,18 +21,18 @@
 #include <stdbool.h>
 #include <errno.h>
 #include "core/alphabet.h"
-#include "core/chardef.h"
+#include "core/chardef_api.h"
 #include "core/codetype.h"
 #include "core/encseq.h"
 #include "core/encseq_metadata.h"
-#include "core/fa.h"
+#include "core/fa_api.h"
 #include "core/logger.h"
 #include "core/readmode.h"
 #include "core/showtime.h"
 #include "core/timer_api.h"
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
-#include "core/mathsupport.h"
+#include "core/mathsupport_api.h"
 #include "esa-fileend.h"
 #include "esa-shulen.h"
 #include "giextract.h"
@@ -189,7 +189,7 @@ static int bwttab2file(Outfileinfo *outfileinfo,
       startpos = gt_suffixsortspace_getdirect(suffixsortspace,pos);
       if (startpos == 0)
       {
-        cc = (GtUchar) UNDEFBWTCHAR;
+        cc = (GtUchar) GT_UNDEFBWTCHAR;
       } else
       {
         if (outfileinfo->outfpbwttab != NULL)
