@@ -16,14 +16,14 @@
 */
 
 #include "core/basename_api.h"
-#include "core/fa.h"
+#include "core/fa_api.h"
 #include "core/log_api.h"
 #include "core/logger.h"
 #include "core/logger_api.h"
-#include "core/ma.h"
-#include "core/mathsupport.h"
-#include "core/minmax.h"
-#include "core/safearith.h"
+#include "core/ma_api.h"
+#include "core/mathsupport_api.h"
+#include "core/minmax_api.h"
+#include "core/safearith_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
 #include "extended/condenseq.h"
