@@ -18,8 +18,8 @@
 #include "core/log.h"
 #include "core/logger.h"
 #include "core/encseq.h"
-#include "core/fa.h"
-#include "core/ma.h"
+#include "core/fa_api.h"
+#include "core/ma_api.h"
 #include "core/output_file_api.h"
 #include "core/option_api.h"
 #include "core/unused_api.h"
