@@ -15,9 +15,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/unused_api.h"
-#include "core/fa.h"
+#include "core/fa_api.h"
 #include "core/timer_api.h"
 #include "core/showtime.h"
 #include "core/logger.h"
