@@ -21,18 +21,18 @@
 #include <string.h>
 #include <sys/types.h>
 
-#include "core/compat.h"
+#include "core/compat_api.h"
 #include "core/fileutils_api.h"
-#include "core/xposix.h"
-#include "core/fa.h"
-#include "core/ma.h"
-#include "core/versionfunc.h"
+#include "core/xposix_api.h"
+#include "core/fa_api.h"
+#include "core/ma_api.h"
+#include "core/versionfunc_api.h"
 #include "core/seq_iterator_sequence_buffer_api.h"
 #include "core/seq_iterator_fastq_api.h"
 #include "core/str_array_api.h"
 #include "core/unused_api.h"
 #include "core/undef_api.h"
-#include "core/versionfunc.h"
+#include "core/versionfunc_api.h"
 #include "core/xansi_api.h"
 #include "core/progressbar.h"
 #include "core/parseutils.h"
