@@ -431,7 +431,7 @@ Test do
       run "#{$scriptsdir}rmwildcard.rb #{$testdata}#{filename}"
       run_test "#{$bin}/gt suffixerator -db #{last_stdout} -dna -v -tis -sds no -des no -md5 no -indexname sfx"
       run_test "#{$bin}/gt dev sfxmap -ownencseq2file -esa sfx"
-      if File.exists?("sfx.ssp")
+      if File.exist?("sfx.ssp")
         run "cmp sfx.ssp sfx2.ssp"
       end
     end
@@ -601,3 +601,11 @@ Test do
   run "#{$bin}/gt dev sfxmap -enumlcpitvtree -esa sfx > noBU.txt"
   run "diff withBU.txt noBU.txt"
 end
+
+Name "gt suffixerator multithreaded -lcp"
+Keywords "gt_suffixerator multithreaded"
+Test do
+  run "#{$bin}/gt -j 3 suffixerator -db #{$testdata}/at1MB -indexname foo " + \
+      "-lcp -suf", :retval => 1
+  grep(last_stderr, /cannot be used when/)
+end
